pydevDAG._attributes._nodetypes module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._attributes package »

# pydevDAG._attributes._nodetypes module

## pydevDAG._attributes._nodetypes

Types of graph nodes.

class `pydevDAG._attributes._nodetypes.` `NodeType`

  Bases: `pydevDAG._attributes._metaclasses.AttributeValue`

  Abstract class that represents a node type.

class `pydevDAG._attributes._nodetypes.` `NodeTypes`

  Bases: `pydevDAG._attributes._metaclasses.AttributeValues`

  Enumeration of node types.

  `DEVICE_PATH` = DevicePath()
  `WWN` = WWN()
  classmethod `values`()

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._attributes package »